@@ -1,7 +1,7 @@
 package fatcontext
 
 import (
-	"github.com/Crocmagnon/fatcontext/pkg/analyzer"
+	"go.augendre.info/fatcontext/pkg/analyzer"
 	"golang.org/x/tools/go/analysis"
 
 	"github.com/golangci/golangci-lint/v2/pkg/config"
