@@ -6,12 +6,11 @@ import (
 
 	"golang.org/x/tools/go/analysis"
 
-	"github.com/golangci/golangci-lint/pkg/golinters/internal"
-
-	"github.com/golangci/golangci-lint/pkg/config"
-	"github.com/golangci/golangci-lint/pkg/goanalysis"
-	nolintlint "github.com/golangci/golangci-lint/pkg/golinters/nolintlint/internal"
-	"github.com/golangci/golangci-lint/pkg/lint/linter"
+	"github.com/golangci/golangci-lint/v2/pkg/config"
+	"github.com/golangci/golangci-lint/v2/pkg/goanalysis"
+	"github.com/golangci/golangci-lint/v2/pkg/golinters/internal"
+	nolintlint "github.com/golangci/golangci-lint/v2/pkg/golinters/nolintlint/internal"
+	"github.com/golangci/golangci-lint/v2/pkg/lint/linter"
 )
 
 const LinterName = nolintlint.LinterName
