@@ -4,8 +4,8 @@ import (
 	"github.com/bombsimon/wsl/v4"
 	"golang.org/x/tools/go/analysis"
 
-	"github.com/golangci/golangci-lint/pkg/config"
-	"github.com/golangci/golangci-lint/pkg/goanalysis"
+	"github.com/golangci/golangci-lint/v2/pkg/config"
+	"github.com/golangci/golangci-lint/v2/pkg/goanalysis"
 )
 
 func New(settings *config.WSLSettings) *goanalysis.Linter {
@@ -23,8 +23,10 @@ func New(settings *config.WSLSettings) *goanalysis.Linter {
 			AllowCuddleWithCalls:             settings.AllowCuddleWithCalls,
 			AllowCuddleWithRHS:               settings.AllowCuddleWithRHS,
 			ForceCuddleErrCheckAndAssign:     settings.ForceCuddleErrCheckAndAssign,
+			AllowCuddleUsedInBlock:           settings.AllowCuddleUsedInBlock,
 			ErrorVariableNames:               settings.ErrorVariableNames,
 			ForceExclusiveShortDeclarations:  settings.ForceExclusiveShortDeclarations,
+			IncludeGenerated:                 true, // force to true because golangci-lint already have a way to filter generated files.
 		}
 	}
 
