@@ -3,12 +3,15 @@ package processors
 import (
 	"path/filepath"
 
-	"github.com/golangci/golangci-lint/pkg/logutils"
-	"github.com/golangci/golangci-lint/pkg/result"
+	"github.com/golangci/golangci-lint/v2/pkg/logutils"
+	"github.com/golangci/golangci-lint/v2/pkg/result"
 )
 
 var _ Processor = (*InvalidIssue)(nil)
 
+// InvalidIssue filters invalid reports.
+//   - non-go files (except `go.mod`)
+//   - reports without file path
 type InvalidIssue struct {
 	log logutils.Log
 }
@@ -22,7 +25,7 @@ func (InvalidIssue) Name() string {
 }
 
 func (p InvalidIssue) Process(issues []result.Issue) ([]result.Issue, error) {
-	tcIssues := filterIssues(issues, func(issue *result.Issue) bool {
+	tcIssues := filterIssuesUnsafe(issues, func(issue *result.Issue) bool {
 		return issue.FromLinter == typeCheckName
 	})
 
